# cus_utilities.mk - "make" command file to relink utilities executables
#
# NOTE:   ORACLE_HOME must be either:
#		. set in the user's environment
#		. passed in on the command line
#		. defined in a modified version of this makefile
#
include $(ORACLE_HOME)/rdbms/lib/env_rdbms.mk

RDBMSBIN=$(ORACLE_HOME)/rdbms/lib/
LDFLAGS=-L$(LIBHOME) -L$(ORACLE_HOME)/rdbms/lib
LDCCOM=$(LINK) $(EXOSFLAGS) $(LDFLAGS) -o $@
ECHODO=$(ORACLE_HOME)/bin/echodo
JAVAVM_SHLIB_SOHOME=$(LIBHOME)


client_sharedlib:
	$(GENCLNTSH)


INSTALL_TARGS=clean iexp iimp isqlldr itkprof irman

ALL_EXECS=exp imp sqlldr tkprof rman


iexp: $(EXP)
	-mv -f $(ORACLE_HOME)/bin/exp $(ORACLE_HOME)/bin/expO
	-mv $(ORACLE_HOME)/rdbms/lib/exp $(ORACLE_HOME)/bin/exp
	-chmod 751 $(ORACLE_HOME)/bin/exp

iimp: $(IMP)
	-mv -f $(ORACLE_HOME)/bin/imp  $(ORACLE_HOME)/bin/impO
	-mv $(ORACLE_HOME)/rdbms/lib/imp $(ORACLE_HOME)/bin/imp
	-chmod 751 $(ORACLE_HOME)/bin/imp

isqlldr: $(SQLLDR)
	-mv -f $(ORACLE_HOME)/bin/sqlldr $(ORACLE_HOME)/bin/sqlldrO
	-mv $(ORACLE_HOME)/rdbms/lib/sqlldr $(ORACLE_HOME)/bin/sqlldr
	-chmod 751 $(ORACLE_HOME)/bin/sqlldr

itkprof: $(TKPROF)
	-mv -f $(ORACLE_HOME)/bin/tkprof $(ORACLE_HOME)/bin/tkprofO
	-mv $(ORACLE_HOME)/rdbms/lib/tkprof $(ORACLE_HOME)/bin/tkprof
	-chmod 751 $(ORACLE_HOME)/bin/tkprof

irman: $(RMAN)
	-mv -f $(ORACLE_HOME)/bin/rman $(ORACLE_HOME)/bin/rmanO
	-mv $(ORACLE_HOME)/rdbms/lib/rman $(ORACLE_HOME)/bin/rman
	-chmod 751 $(ORACLE_HOME)/bin/rman

singletask: iexpst iimpst isqlldrst

iexpst: expst
	-mv -f $(ORACLE_HOME)/bin/expst $(ORACLE_HOME)/bin/expstO
	-mv expst $(ORACLE_HOME)/bin/expst
	-chmod 751 $(ORACLE_HOME)/bin/expst

iimpst: impst
	-mv -f $(ORACLE_HOME)/bin/impst $(ORACLE_HOME)/bin/impstO
	-mv impst $(ORACLE_HOME)/bin/impst
	-chmod 751 $(ORACLE_HOME)/bin/impst

isqlldrst: sqlldrst
	-mv -f $(ORACLE_HOME)/bin/sqlldrst $(ORACLE_HOME)/bin/sqlldrstO
	-mv sqlldrst $(ORACLE_HOME)/bin/sqlldrst
	-chmod 751 $(ORACLE_HOME)/bin/sqlldrst


$(IMP) : $(IMPMAI) $(DEF_OPT) $(SSDBED)
	$(SILENT)$(ECHO) " - Linking Import utility (imp)"
	$(LDCCOM) $(IMPMAI) $(SSDBED) $(DEF_OPT) $(LIBDBTOOLS) $(TTLIBS)

$(EXP) : $(EXPMAI) $(DEF_OPT) $(SSDBED)
	$(SILENT)$(ECHO) " - Linking Export utility (exp)"
	$(LDCCOM) $(EXPMAI) $(SSDBED) $(DEF_OPT) $(LIBDBTOOLS) $(TTLIBS)

$(SQLLDR) : $(LDRMAI) $(DEF_OPT) $(SSDBED)
	$(SILENT)$(ECHO) " - Linking SQL*Loader utility (sqlldr)"
	$(LDCCOM) $(LDRMAI) $(SSDBED) $(DEF_OPT) \
	$(RDBMSLIB)$(LIL_OFF) $(LIBDBTOOLS) $(TTLIBS)

$(SQLLDR_LIL) : $(LIL_ON) $(LDRMAI) $(DEF_OPT) $(SSDBED)
	$(SILENT)$(ECHO) " - Linking SQL*Loader utility (sqlldr)"
	$(LDCCOM) $(LDRMAI) $(SSDBED) $(DEF_OPT) $(LIBDBTOOLS) $(TTLIBS) $(LIL_ON)

$(TKPROF) : $(TKPMAI)  $(SSDBED) $(DEF_OPT)
	$(SILENT)$(ECHO) " - Linking performance trace utility (tkprof)"
	$(LDCCOM) $(TKPMAI) $(SSDBED) $(DEF_OPT) $(TTLIBS)

$(RMAN) : $(SSKRMED) $(SKRMPT) $(S0MAIN) $(DEF_OPT)
	$(SILENT)$(ECHO) " - Linking recovery manager (rman)"
	$(LDCCOM) $(S0MAIN) $(SSKRMED) $(SKRMPT) $(DEF_OPT) \
	$(LIBDBTOOLS) $(LLIBCLIENT) $(LLIBSQL) $(LLIBPLSQL) \
	$(LLIBSLAX) $(LLIBPLSQL) $(TTLIBS)


expst: $(EXPMAI) $(DEF_OPT) $(SSDBED)
	$(SILENT)$(ECHO) " - Linking Singletask Export utility (exp)"
	$(ECHO) " - $(SHLIBJOX)"
	$(LDCCOM) $(EXPMAI) $(SSDBED) $(DEF_OPT) $(LIBDBTOOLS) $(SHLIBJOX) $(STLIBS)

impst: $(IMPMAI) $(DEF_OPT) $(SSDBED)
	$(SILENT)$(ECHO) " - Linking Singletask Import utility (imp)"
	$(LDCCOM) $(IMPMAI) $(SSDBED) $(DEF_OPT) $(LIBDBTOOLS) $(SHLIBJOX) $(STLIBS)

sqlldrst: $(LDRMAI) $(DEF_OPT) $(SSDBED)
	$(SILENT)$(ECHO) " - Linking Singletask SQL*Loader utility (sqlldr)"
	$(LDCCOM) $(LDRMAI) $(SSDBED) $(DEF_OPT) \
	$(RDBMSLIB)$(LIL_OFF) $(LIBDBTOOLS) $(SHLIBJOX) $(STLIBS)

clean:
	-rm -f $(ALL_EXECS)

preinstall:
	-chmod 755 $(ORACLE_HOME)/bin
	
install: preinstall $(INSTALL_TARGS)

singletask: iexpst iimpst isqlldrst
